.. index:: IceProdServer
.. _IceProdServer:



IceProd Server
==============

An overview of concepts and design patterns are available in:

.. toctree::
    :titlesonly:

    Server Details <details/index>

REST API
--------

The low-level REST API.  This is the interface the server shows to
the rest of the world.

.. toctree::
   :maxdepth: 2

   REST API <rest_api/index>

Regular Classes
---------------

Utilities, helpers, shared code, and other bits and pieces.

.. toctree::
   :maxdepth: 2
   :glob:

   *
